@@ -61,14 +61,6 @@ class FormulaBit(Container):
     self.contents = []
     self.output = ContentsOutput()
 
-  def glob(self, pos, check):
-    "Glob a bit of text that satisfies a check"
-    glob = ''
-    while not pos.finished() and check(pos):
-      glob += pos.current()
-      pos.skip(pos.current())
-    return glob
-
   def clone(self):
     "Return an exact copy of self"
     type = self.__class__
@@ -140,7 +132,6 @@ class WholeFormula(FormulaBit):
     for index, bit in enumerate(self.contents):
       bit.process()
       if bit.type == 'alpha':
-        Trace.debug('Alpha ' + unicode(bit))
         # make variable
         self.contents[index] = TaggedBit().complete([bit], 'i')
       elif bit.type == 'font' and index > 0:
